## Sourcemapper

### xml _(Source Mapper)_

<p style="word-wrap: break-word">This mapper converts XML input to Siddhi event. Transports which accepts XML messages can utilize this extension to convert the incoming XML message to Siddhi event. Users can either send a pre-defined XML format where event conversion will happen without any configs or can use xpath to map from a custom XML message.</p>

#### Syntax

```
@source(..., @map(type="xml", namespaces="<STRING>", enclosing.element="<STRING>", fail.on.missing.attribute="<BOOL>")
```

##### Query Parameters

<table>
    <tr>
        <th>Name</th>
        <th>Description</th>
        <th>Default Value</th>
        <th>Possible Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td valign="top">namespaces</td>
        <td valign="top"><p style="word-wrap: break-word">Used to provide namespaces used in the incoming XML message beforehand to configure xpath expressions. User can provide a comma separated list. If these are not provided xpath evaluations will fail</p></td>
        <td valign="top">None</td>
        <td valign="top">STRING</td>
        <td valign="top">Yes</td>
        <td valign="top">No</td>
    </tr>
    <tr>
        <td valign="top">enclosing.element</td>
        <td valign="top"><p style="word-wrap: break-word">Used to specify the enclosing element in case of sending multiple events in same XML message. WSO2 DAS will treat the child element of given enclosing element as events and execute xpath expressions on child elements. If enclosing.element is not provided multiple event scenario is disregarded and xpaths will be evaluated with respect to root element.</p></td>
        <td valign="top">Root element</td>
        <td valign="top">STRING</td>
        <td valign="top">Yes</td>
        <td valign="top">No</td>
    </tr>
    <tr>
        <td valign="top">fail.on.missing.attribute</td>
        <td valign="top"><p style="word-wrap: break-word">This can either have value true or false. By default it will be true. This attribute allows user to handle unknown attributes. By default if an xpath execution fails or returns null DAS will drop that message. However setting this property to false will prompt DAS to send and event with null value to Siddhi where user can handle it accordingly(ie. Assign a default value)</p></td>
        <td valign="top">True</td>
        <td valign="top">BOOL</td>
        <td valign="top">Yes</td>
        <td valign="top">No</td>
    </tr>
</table>



#### Examples

##### Example 1

```
@source(type='inMemory', topic='stock', @map(type='xml'))
define stream FooStream (symbol string, price float, volume long);

```
<p style="word-wrap: break-word">Above configuration will do a default XML input mapping. Expected input will look like below.&lt;events&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&lt;event&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;symbol&gt;WSO2&lt;/symbol&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;price&gt;55.6&lt;/price&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;volume&gt;100&lt;/volume&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&lt;/event&gt;<br>&lt;/events&gt;<br></p>

##### Example 2

```
@source(type='inMemory', topic='stock', @map(type='xml', namespaces = "dt=urn:schemas-microsoft-com:datatypes", enclosing.element="//portfolio", @attributes(symbol = "company/symbol", price = "price", volume = "volume")))
define stream FooStream (symbol string, price float, volume long);
```
<p style="word-wrap: break-word">Above configuration will perform a custom XML mapping. In the custom mapping user can add xpath expressions representing each event attribute using @attribute annotation. Expected input will look like below.<br>&lt;portfolio xmlns:dt="urn:schemas-microsoft-com:datatypes"&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&lt;stock exchange="nasdaq"&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;volume&gt;100&lt;/volume&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;company&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;symbol&gt;WSO2&lt;/symbol&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;/company&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;price dt:type="number"&gt;55.6&lt;/price&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&lt;/stock&gt;<br>&lt;/portfolio&gt;</p>

## Sinkmapper

### xml _(Sink Mapper)_

<p style="word-wrap: break-word">This mapper converts Siddhi output events to XML before they are published via transports that publish in XML format. Users can either send a pre-defined XML format or a custom XML message containing event data.</p>

#### Syntax

```
@sink(..., @map(type="xml", validate.xml="<BOOL>", enclosing.element="<STRING>")
```

##### Query Parameters

<table>
    <tr>
        <th>Name</th>
        <th>Description</th>
        <th>Default Value</th>
        <th>Possible Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td valign="top">validate.xml</td>
        <td valign="top"><p style="word-wrap: break-word">This parameter specifies whether the XML messages generated should be validated or not. If this parameter is set to true, messages that do not adhere to proper XML standards are dropped. </p></td>
        <td valign="top">false</td>
        <td valign="top">BOOL</td>
        <td valign="top">Yes</td>
        <td valign="top">No</td>
    </tr>
    <tr>
        <td valign="top">enclosing.element</td>
        <td valign="top"><p style="word-wrap: break-word">When an enclosing element is specified, the child elements (e.g., the immediate child elements) of that element are considered as events. This is useful when you need to send multiple events in a single XML message. When an enclosing element is not specified, one XML message per every event will be emitted without enclosing.</p></td>
        <td valign="top">None in custom mapping and &lt;events&gt; in default mapping</td>
        <td valign="top">STRING</td>
        <td valign="top">No</td>
        <td valign="top">No</td>
    </tr>
</table>



#### Examples

##### Example 1

```
@sink(type='inMemory', topic='stock', @map(type='xml'))
define stream FooStream (symbol string, price float, volume long);

```
<p style="word-wrap: break-word">Above configuration will do a default XML input mapping which will generate below output<br>&lt;events&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&lt;event&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;symbol&gt;WSO2&lt;/symbol&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;price&gt;55.6&lt;/price&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;volume&gt;100&lt;/volume&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&lt;/event&gt;<br>&lt;/events&gt;<br></p>

##### Example 2

```
@sink(type='inMemory', topic='{{symbol}}', @map(type='xml', enclosing.element='<portfolio>', validate.xml='true', @payload( "<StockData><Symbol>{{symbol}}</Symbol><Price>{{price}}</Price></StockData>")))
define stream BarStream (symbol string, price float, volume long);
```
<p style="word-wrap: break-word">Above configuration will perform a custom XML mapping. Inside @payload you can specify the custom template that you want to send the messages out and addd placeholders to places where you need to add event attributes.Above config will produce below output XML message<br>&lt;portfolio&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&lt;StockData&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;Symbol&gt;WSO2&lt;/Symbol&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;Price&gt;55.6&lt;/Price&gt;<br>&nbsp;&nbsp;&nbsp;&nbsp;&lt;/StockData&gt;<br>&lt;/portfolio&gt;</p>

